@@ -201,79 +201,6 @@ split_mat <- function (obj, by) {
   res
 }
 
-#' This function takes an scRNAseq counts matrix as an input (cells in rows x genes in cols) and outputs a matrix of cells x 3 covariates (number of genes detected, sequencing depth and mitochondrial gene expression). This covariate matrix can then be used to match cells and perform stratified permutation.
-#' @param datamat is cells x genes matrix from an scRNAseq experiment. Could be non-UMI or UMI counts.
-#' @return A list of scRNAseq matrices subsetted by KEGG Pathways, so list[[n]] corresponds to the n^th pathway.
-#' @export
-#' @import Seurat
-#' @importFrom  Matrix rowSums
-matchpar <- function(datamat) {
-  library_size <- rowSums(datamat)
-  genes_detected <- apply(datamat, 1, function(x) length(x[x>0]))
-  mito.genes = grep(pattern = "^MT-", x = colnames(x = datamat), value = TRUE)
-  percent.mito <- Matrix::rowSums(datamat[,mito.genes])/Matrix::rowSums(datamat)
-  d1 <- cbind(library_size,genes_detected)
-  d2 <- cbind(d1,percent.mito)
-  return(d2)
-}
-
-#' This function takes an scRNAseq counts matrix as an input (cells in rows x genes in cols) and outputs a list of cells x pathway matrices
-#' @param datamat is cells x genes matrix from an scRNAseq experiment. Could be non-UMI or UMI counts.
-#' @param orgsm specifies whether the species is mouse ("Mm"), human ("Hs) or C. elegans ("Ce").
-#' @return A list of scRNAseq matrices subsetted by KEGG Pathways, so list[[n]] corresponds to the n^th pathway.
-#' @export
-#' @import org.Hs.eg.db
-#' @import org.Mm.eg.db
-#' @import org.Ce.eg.db
-#' @importFrom  AnnotationDbi mappedkeys
-scPath <- function(datamat, orgsm) {
-  if(orgsm=="Hs")  { 
-    kegg <- org.Hs.egPATH2EG 
-    x <- org.Hs.egSYMBOL
-  }
-  if(orgsm=="Mm")  { 
-    kegg <- org.Mm.egPATH2EG
-    x <- org.Mm.egSYMBOL
-  }
-  if(orgsm=="Ce")  { 
-    kegg <- org.Ce.egPATH2EG
-    x <- org.Ce.egSYMBOL
-  }
-  mapped <- AnnotationDbi::mappedkeys(kegg)
-  kegg2 <- as.list(kegg[mapped])
-  ## kegg2 is a list where each [] index is a pathway and [[]] indices are genes, all in numeric/ID form
-  KEGGList <- matrix(as.numeric(unlist(kegg2))) #Extract a List of all genes (>16K) which are functionally annotated in KEGG
-  sums <- c()
-  for (i in 1:length(kegg2)) { sums[i] <- length(kegg2[[i]])}
-  pathnames <- c()
-  for (i in 1:length(kegg2)) {
-    pathnames[i] <- list(rep((names(kegg2)[i]),sums[i]))
-  }
-  pathlist <- matrix(unlist(pathnames))
-  
-  KEGGMap <- as.data.frame(cbind(pathlist,KEGGList))
-  colnames(KEGGMap) <- c("Pathway ID","Gene Entrez ID")
-  
-  mapped_genes <- AnnotationDbi::mappedkeys(x)
-  x2 <- as.list(x[mapped_genes])
-  entrezID <- names(x2)
-  kegg_gene <- matrix(unlist(x2))
-  RefID <- as.data.frame(cbind(entrezID,kegg_gene))
-  ##RefID has two cols, first with Entrez IDs, second with the corresponding gene names
-  match_genes <- RefID[match(KEGGMap$`Gene Entrez ID`,RefID$entrezID),2]
-  KEGGMap2 <- cbind(KEGGMap,match_genes) #KEGGMap2 contains Pathway ID, Gene Entrez ID, Gene Name
-  
-  Gene_Path <- split_mat(KEGGMap2,"Pathway ID")
-  #Gene_Path is a sub-setted list of KEGGMap 2 with length 229 (# of pathways)
-  ## Now should be able to subset sc Matrix using Gene_Path[[i]]$match_genes
-  data_bypath <- c()
-  for (i in 1:length(Gene_Path)) {
-    data_bypath[[i]] <- datamat[,intersect(colnames(datamat),Gene_Path[[i]]$match_genes)]
-  }
-  return(data_bypath)
-}
-
-
 #' Calculates the pairwise crosscounts for the K classes being examined
 #' @param nvec is a vector containing the sizes of the K different classes
 #' @param apmat is the data matrix containing pooled data from each of the K classess, on which optimal non-bipartite matching is performed.
